@@ -23,14 +23,17 @@ sub aggregate {
     my $url = $args->{feed}->url;
     $context->log(info => "Fetch $url");
 
-    my $agent = Plagger::UserAgent->new;
-    my $response = $agent->get($url);
+    my $agent    = Plagger::UserAgent->new;
+    my $response = $agent->fetch($url, $self);
 
-    unless ($response->is_success) {
-        $context->log(error => "GET $url failed: " . $response->status_line);
+    unless ($response) {
+        $context->log(error => "GET $url failed: " . $response->status);
         return;
     }
 
+    # TODO: handle 301 Moved Permenently and 410 Gone
+    $context->log(debug => $response->status . ": $url");
+
     $self->handle_feed($url, \$response->content);
 }
 
@@ -82,6 +85,8 @@ sub handle_feed {
         $entry->id($e->id);
         $entry->body($e->content->body);
 
+        $entry->{feed_entry} = $e; # xxx for now
+
         $feed->add_entry($entry);
     }
 
