@@ -8,7 +8,7 @@ sub register {
     my($self, $context) = @_;
     $context->register_hook(
         $self,
-        'publish.add_feed' => \&add_feed,
+        'publish.feed' => \&add_feed,
         'publish.finalize' => \&finalize,
     );
 }
