@@ -2,6 +2,8 @@ package Plagger::UserAgent;
 use strict;
 use base qw( LWP::UserAgent );
 
+use URI::Fetch;
+
 sub new {
     my $class = shift;
     my $self  = $class->SUPER::new();
@@ -10,5 +12,14 @@ sub new {
     $self;
 }
 
+sub fetch {
+    my($self, $url, $plugin) = @_;
+
+    URI::Fetch->fetch($url,
+        UserAgent => $self,
+        $plugin ? (Cache => $plugin->cache) : (),
+    );
+}
+
 1;
 
